@@ -1,6 +1,8 @@
 #' @title get_manual
 #' @author Simon Goring \email{goring@@wisc.edu}
 #' @description Open up the Neotoma manual homepage.
+#' @importFrom utils browseURL
+#' @importFrom rlang is_interactive
 #' @examples {
 #' # This call does not work from `source()` calls or in testing.
 #' # interactive() just lets us know you are interacting with the console:
@@ -8,16 +10,14 @@
 #'  get_manual()
 #' }
 #' }
-#' 
-#' @importFrom utils browseURL
-#' @importFrom rlang is_interactive
 #' @returns NULL side effect for opening browser with the manual
+#' @md
 #' @export
 get_manual <- function() {
-  if (rlang::is_interactive()) {
+  if (is_interactive()) {
     browseURL(url = "https://open.neotomadb.org/manual/")
   } else {
     stop("Browser window will not open if interactive() mode is FALSE.")
   }
   return(NULL)
-}
+}
\ No newline at end of file
