@@ -1,19 +1,15 @@
 #' @title get_sites
+#' @name get_sites
 #' @author Socorro Dominguez \email{dominguezvid@wisc.edu}
-#' @import gtools
-#' @import lubridate
-#' @importFrom methods new
-#' @param x A numeric vector of unique Neotoma site identifiers.
-#' @param ... One of a set of possible query parameters discussed in details.
+#' @param x Use a single integer or vector of integers representing 
+#' unique Neotoma site identifiers (siteids) to extract site information.
+#' @param ... accepted arguments, see details for more information.
 #' @description
-#' The get_sites() function is a wrapper for the Neotoma `sites` API
+#' The `get_sites` function is a wrapper for the Neotoma `sites` API
 #' endpoint.
 #' The function takes parameters defined by the user and returns a list
 #' of site information supplied by the Neotoma Paleoecological Database.
 #' The user may define all or none of the possible fields.
-#' @param x Use a single integer or vector of integers representing 
-#' unique Neotoma site identifiers (siteids) to extract site information.
-#' @param ... accepted arguments, see details for more information.
 #' @details
 #' A `site` object in Neotoma is a physical location at which one or more
 #' collection units are located. Each collection unit may have one or more
@@ -27,7 +23,8 @@
 #'  * `siteid`  The unique site ID (integer) in Neotoma. Can be passed as a
 #' vector of site IDs.
 #'  * `sitename`  The site name, or approximate match using the % wildcard.
-#'  * `database`  The constituent database for the record. See `get_table("constituentdatabases")`
+#'  * `database`  The constituent database for the record.
+#' See `get_table("constituentdatabases")`
 #'  * `altmin`  The minimum altitude range for site elevation (in meters).
 #'  * `altmax`  The maximum altitude range for site elevation (in meters).
 #'  * `datasetid`  The unique dataset ID (integer) in Neotoma. Can be passed
@@ -68,10 +65,18 @@
 #' @examples
 #' \donttest{
 #' ## Find sites with a min altitude of 12m and a max altitude of 25m
-#' sites_12to25 <- get_sites(altmin=12, altmax=25)
+#' tryCatch({
+#'   sites_12to25 <- get_sites(altmin=12, altmax=25)
+#' }, error = function(e) {
+#'   message("Neotoma server not responding. Try again later.")
+#' })
 #' ## Return all sites, using a minimum altitude of 2500m (returns >500 sites):
-#' sites_2500 <- get_sites(altmin=2500, all_data = TRUE)
-#' ## To find sites in Brazil
+#' tryCatch({
+#'   sites_2500 <- get_sites(altmin=2500, all_data = TRUE)
+#' }, error = function(e) {
+#'   message("Neotoma server not responding. Try again later.")
+#' })
+#'   ## To find sites in Brazil
 #' brazil <- '{"type": "Polygon",
 #' "coordinates": [[
 #'  [-73.125, -9.102096738726443],
@@ -79,8 +84,8 @@
 #'  [-36.5625,-7.710991655433217],
 #'  [-68.203125,13.923403897723347],
 #'  [-73.125,-9.102096738726443]]]}'
+#' tryCatch({
 #' brazil_sites <- get_sites(loc = brazil[1])
-#'
 #' # Finding all sites with Liliaceae pollen in 1000 year bins:
 #' lilysites <- c()
 #' for (i in seq(0, 10000, by = 1000)) {
@@ -90,41 +95,36 @@
 #'                     all_data = TRUE)
 #'   lilysites <- c(lilysites, length(lily))
 #' }
+#' }, error = function(e) {
+#'   message("Neotoma server not responding. Try again later.")
+#' })
 #' }
+#' @md
 #' @export
 get_sites <- function(x = NA, ...) {
-  if (!missing(x)) {
-    UseMethod("get_sites", x)
+  if (missing(x)) {
+    UseMethod("get_sites", "default")
   } else {
-    UseMethod("get_sites", NA)
+    UseMethod("get_sites", x)
   }
 }
 
-
-#' @title Get Site Information for Fossil Sites
-#' @param x The numeric site ID from Neotoma
-#' @param ... accepted arguments if numeric all_data
-#' @returns The function returns either a single item of class `"try-error"`
-#' describing the reason for failure (either misdefined parameters or an error
-#' from the Neotoma API), or a table of sites, with rows corresponding to the
-#' number of individual sites returned by the Neotoma API.
-#' Each "site" object contains 6 parameters that can be accessed as well:
-#' siteid, sitename, location, altitude, description,
-#' limited collection units information.
-#'  * `loc` An `sf` object that describes site's location.
-#'  * `collunits` limited information on collunits
-#' @examples {
-#' ## Find all sites by numeric siteid:
-#' sites <- get_sites(seq(1,3))
-#' }
-#' @export
+#' @rdname get_sites
+#' @method get_sites numeric
+#' @exportS3Method get_sites numeric
 get_sites.numeric <- function(x, ...) {
   if (length(x) > 0) {
     siteids <- paste0(x, collapse = ",")
   }
-  base_url <- paste0("data/sites/", siteids)
-  result <- parseURL(base_url, ...)
-  if (length(result[2]$data) > 0) {
+  baseURL <- paste0("data/sites/", siteids)
+  result <- tryCatch(
+    parseURL(baseURL, ...),
+    error = function(e) {
+      stop("API call failed: ", e$message)
+      NULL
+    }
+  )
+  if (!is.null(result) && length(result[2]$data) > 0) {
     output <- parse_site(result)
     return(output)
   } else {
@@ -132,45 +132,44 @@ get_sites.numeric <- function(x, ...) {
   }
 }
 
-#' @title get_sites
-#' @author Socorro Dominguez \email{dominguezvid@wisc.edu}
-#' @import gtools
-#' @import lubridate
-#' @import sf
-#' @importFrom methods new
-#' @importFrom utils URLencode
-#' @param ... One of a set of possible query parameters discussed in details.
-#' @returns The function returns either a single item of class `"try-error"`
-#' describing the reason for failure (either misdefined parameters or an error
-#' from the Neotoma API), or a table of sites, with rows corresponding to the
-#' number of individual sites returned by the Neotoma API.
-#' Each "site" object contains 6 parameters that can be accessed as well:
-#' siteid, sitename, location, altitude, description,
-#' limited collection units information.
-#'  * `loc` An `sf` object that describes site's location.
-#'  * `collunits` limited information on collunits
-#' @export
+#' @rdname get_sites
+#' @method get_sites default
+#' @exportS3Method get_sites default
 get_sites.default <- function(...) {
   cl <- as.list(match.call())
   cl[[1]] <- NULL
   cl <- lapply(cl, eval, envir = parent.frame())
+  if ("siteid" %in% names(cl)) {
+    # redirect to numeric method
+    if ("all_data" %in% names(cl)) {
+      all_data <- cl$all_data
+    } else {
+      all_data <- FALSE
+    }
+    output <- get_sites(x = cl$siteid, all_data = all_data)
+    return(output)
+  }
   params <- get_params("sites")
   if (!all(names(cl) %in% params)) {
-    warning("Some parameters seem invalid. The current accepted parameters are: ",
+    warning("Some parameters seem invalid.
+             The current accepted parameters are: ",
             paste(unlist(params), collapse = ", "))
   }
-  oo <- options(scipen = 9999999)
+  oo <- options(scipen = 9999)
   on.exit(options(oo))
-
-    base_url <- paste0("data/sites")
-    result <- parseURL(base_url, ...) 
-    
-    result <- result %>%
-      cleanNULL()
-
-  if (is.null(result$data[1][[1]])) {
+  baseURL <- paste0("data/sites")
+  result <- tryCatch(
+    parseURL(baseURL, ...),
+    error = function(e) {
+      stop("API call failed: ", e$message)
+      NULL
+    }
+  )
+  if (is.null(result) || is.null(result$data[1][[1]])) {
     return(NULL)
   } else {
+    result <- result %>%
+      cleanNULL()
     output <- parse_site(result)
     return(output)
   }
